==> darwin-shared-0.1.15.tar.gz: darwin-shared-0.1.15/darwin/handlers/base.py <==
from json import dumps, loads
from webapp2 import RequestHandler
from ..utils.language import Language
from ..utils.error import errorUnknownSource
from ..utils.microservices import Microservice
from ..utils.metadata import Metadata
from ..models.error import ErrorModel


restrictedAccessProjectIds = [
    Microservice.getProjectId(Microservice.transfer),
    Microservice.getProjectId(Microservice.workspace),
    Microservice.getProjectId(Microservice.bank),
    Microservice.getProjectId(Microservice.charge),
    Microservice.getProjectId(Microservice.team),
    Microservice.getProjectId(Microservice.edi)
]

freeAccessProjectIds = [
    Microservice.getProjectId(Microservice.gateway)
]


class BaseHandler(RequestHandler):

    def dispatch(self):
        currentProjectId = Metadata.getProjectId()
        incomingAppId = self.getHeaders().get("X-Appengine-Inbound-Appid")
        isNotTaskQueue = not self.getHeaders().get("X-AppEngine-TaskName") and not self.getHeaders().get("X-AppEngine-QueueName")
        isNotFreeAccessProjectId = not currentProjectId in freeAccessProjectIds
        isNotInternalAccess = not incomingAppId in restrictedAccessProjectIds + freeAccessProjectIds
        isNotPubSub = not "CloudPubSub-Google" == self.getUserAgent()
        if isNotFreeAccessProjectId and isNotInternalAccess and isNotTaskQueue and isNotPubSub:
            return self.sendJson(errorUnknownSource(language=self.getLanguage()))
        super(BaseHandler, self).dispatch()

    def getIp(self):
        return self.request.remote_addr

    def getBody(self):
        return self.request.body

    def getJsonBody(self):
        try:
            return loads(self.request.body)
        except:
            return {}

    def getParameter(self, parameter, default=""):
        return self.request.get(parameter, default)

    def getHeaders(self):
        return self.request.headers

    def getLanguage(self):
        language = self.getHeaders().get("Accept-Language")
        return language if Language.isValid(language) else Language.english

    def getUserAgent(self):
        return self.getHeaders().get("User-Agent", "")

    def sendJson(self, obj, headers=None, status=None):
        headers = headers or {}
        headers.update({"Content-Type": "application/json"})
        status = status if status else (400 if ErrorModel.isObject(obj) else 200)
        self.sendContent(content=dumps(obj), headers=headers, status=status)

    def sendContent(self, content, headers=None, status=200):
        self.response.status = status
        self.response.headers = headers or {}
        self.response.headers["Access-Control-Allow-Origin"] = "*"
        self.response.out.write(content)

    def options(self, *args, **data):
        self.response.headers["Access-Control-Allow-Origin"] = "*"
        self.response.headers["Access-Control-Allow-Headers"] = "Origin, X-Requested-With, Content-Type, Accept, Access-Token"
        self.response.headers["Access-Control-Allow-Methods"] = "POST, GET, PUT, DELETE"

==> darwin-shared-0.2.21.tar.gz: darwin-shared-0.2.21/darwin/handlers/base.py <==
from json import dumps, loads
from webapp2 import RequestHandler
from ..utils.language import Language
from ..utils.error import errorUnknownSource
from ..utils.microservices import Microservice
from ..utils.metadata import Metadata
from ..models.error import ErrorModel


restrictedAccessProjectIds = [
    Microservice.getProjectId(Microservice.transfer),
    Microservice.getProjectId(Microservice.workspace),
    Microservice.getProjectId(Microservice.bank),
    Microservice.getProjectId(Microservice.charge),
    Microservice.getProjectId(Microservice.team),
    Microservice.getProjectId(Microservice.edi),
    Microservice.getProjectId(Microservice.auth),
    Microservice.getProjectId(Microservice.address),
    Microservice.getProjectId(Microservice.webhook),
    Microservice.getProjectId(Microservice.pdf)
]

freeAccessProjectIds = [
    Microservice.getProjectId(Microservice.gateway)
]


class BaseHandler(RequestHandler):

    def dispatch(self):
        currentProjectId = Metadata.getProjectId()
        isNotTaskQueue = not self.getHeaders().get("X-AppEngine-TaskName") and not self.getHeaders().get("X-AppEngine-QueueName")
        isNotFreeAccessProjectId = not currentProjectId in freeAccessProjectIds
        isNotInternalAccess = not self.getInboundProjectId() in restrictedAccessProjectIds + freeAccessProjectIds
        isNotPubSub = not "CloudPubSub-Google" == self.getUserAgent()
        if isNotFreeAccessProjectId and isNotInternalAccess and isNotTaskQueue and isNotPubSub:
            return self.sendJson(errorUnknownSource(language=self.getLanguage()))
        super(BaseHandler, self).dispatch()

    def getInboundProjectId(self):
        return self.getHeaders().get("X-Appengine-Inbound-Appid")

    def getIp(self):
        return self.request.remote_addr

    def getBody(self):
        return self.request.body

    def getJsonBody(self):
        try:
            return loads(self.request.body)
        except:
            return {}

    def getDictBody(self):
        body = self.getJsonBody()
        return body if isinstance(body, dict) else {}

    def getParameter(self, parameter, default=""):
        return self.request.get(parameter, default)

    def getHeaders(self):
        return self.request.headers

    def getLanguage(self):
        language = self.getHeaders().get("Accept-Language")
        return language if Language.isValid(language) else Language.english

    def getUserAgent(self):
        return self.getHeaders().get("User-Agent", "")

    def workspaceId(self):
        return self.getHeaders().get("Workspace-Id")

    def userId(self):
        return self.getHeaders().get("User-Id")

    def userEmail(self):
        return self.getHeaders().get("User-Email")

    def userName(self):
        return self.getHeaders().get("User-Name")

    def userIp(self):
        return self.getHeaders().get("Ip") or self.getIp()

    def userRoles(self):
        return [role for role in self.getHeaders().get("User-Roles", "").split(",") if role]

    def sendJson(self, obj, headers=None, status=None):
        headers = headers or {}
        headers.update({"Content-Type": "application/json"})
        status = status if status else (400 if ErrorModel.isObject(obj) else 200)
        self.sendContent(content=dumps(obj), headers=headers, status=status)

    def sendContent(self, content, headers=None, status=200):
        self.response.status = status
        self.response.headers = headers or {}
        self.response.headers["Access-Control-Allow-Origin"] = "*"
        self.response.out.write(content)

    def options(self, *args, **data):
        self.response.headers["Access-Control-Allow-Origin"] = "*"
        self.response.headers["Access-Control-Allow-Headers"] = "Origin, X-Requested-With, Content-Type, Accept, Access-Token"
        self.response.headers["Access-Control-Allow-Methods"] = "POST, GET, PUT, DELETE"
        self.response.headers["Access-Control-Max-Age"] = "1728000"
